# load packages

library(nlme)

# import data and name variables

wisc3raw <- read.table("~/Desktop/wisc3raw.dat", quote="\"")

names(wisc3raw) = c('id', 'verb1', 'verb2', 'verb4', 'verb6', 'perfo1', 'perfo2', 'perfo4', 'perfo6',
                    'info1', 'comp1', 'simi1', 'voca1', 'info6', 'comp6', 'simi6', 'voca6', 'momed', 'grad', 'constant')

# stack data with 4 rows per person

wiscstacked <- data.frame(id = wisc3raw$id, grad = wisc3raw$grad,
  stack(wisc3raw,select = perfo1:perfo6)) 

# change name of stacked outcome variable in 3rd column from "values" to "perform"

names(wiscstacked)[c(3)] <- c('perform')

# compute years (time) variable (grade centered at kindergarten assessment)

wiscstacked$years[wiscstacked$ind == 'perfo1'] <- 0
wiscstacked$years[wiscstacked$ind == 'perfo2'] <- 1
wiscstacked$years[wiscstacked$ind == 'perfo4'] <- 3
wiscstacked$years[wiscstacked$ind == 'perfo6'] <- 5

wiscstacked$years2[wiscstacked$ind == 'perfo1'] <- 0
wiscstacked$years2[wiscstacked$ind == 'perfo2'] <- 1
wiscstacked$years2[wiscstacked$ind == 'perfo4'] <- 9
wiscstacked$years2[wiscstacked$ind == 'perfo6'] <- 25

# ex1: intercept-only growth model

icept <- lme(fixed = perform ~ 1 , random = ~ 1 |id, data = wiscstacked)
summary(icept)

# ex2: linear growth model

linear <- lme(fixed = perform ~ years, random = ~ years|id, data = wiscstacked)
summary(linear)

# ex3: quadratic growth model

quad <- lme(fixed = perform ~ years + years2, random = ~ years|id, data = wiscstacked)
summary(quad)
