# load packages

library(lavaan)

# import data and name variables

wisc3raw <- read.table("D:/Workshops/APA_2015/Section C_SEM/wisc3raw.dat")

names(wisc3raw) = c('id', 'verb1', 'verb2', 'verb4', 'verb6', 'perfo1', 'perfo2', 'perfo4', 'perfo6',
'info1', 'comp1', 'simi1', 'voca1', 'info6', 'comp6', 'simi6', 'voca6', 'momed', 'grad', 'constant')

# ex1: intercept-only growth model

intercept <- '
b0n =~ 1*perfo1 + 1*perfo2 + 1*perfo4 + 1*perfo6
perfo1 ~~ res*perfo1
perfo2 ~~ res*perfo2
perfo4 ~~ res*perfo4
perfo6 ~~ res*perfo6
'

fiticept <- growth(intercept, data = wisc3raw, mimic = "mplus")
summary(fiticept, fit.measures = TRUE)

# ex2: linear growth model

linear <- '
b0n =~ 1*perfo1 + 1*perfo2 + 1*perfo4 + 1*perfo6
b1n =~ 0*perfo1 + 1*perfo2 + 3*perfo4 + 5*perfo6
perfo1 ~~ res*perfo1
perfo2 ~~ res*perfo2
perfo4 ~~ res*perfo4
perfo6 ~~ res*perfo6
'

fitlinear <- growth(linear, data = wisc3raw, mimic = "mplus")
summary(fitlinear, fit.measures = TRUE)

# ex3: quadratic growth model

quad <- '
b0n =~ 1*perfo1 + 1*perfo2 + 1*perfo4 + 1*perfo6
b1n =~ 0*perfo1 + 1*perfo2 + 3*perfo4 + 5*perfo6
b2n =~ 0*perfo1 + 1*perfo2 + 9*perfo4 + 25*perfo6
b2n ~~ 0*b2n
perfo1 ~~ res*perfo1
perfo2 ~~ res*perfo2
perfo4 ~~ res*perfo4
perfo6 ~~ res*perfo6
'

fitquad <- growth(quad, data = wisc3raw, mimic = "mplus")
summary(fitquad, fit.measures = TRUE)

# ex4: latent basis growth model

basis <- '
b0n =~ 1*perfo1 + 1*perfo2 + 1*perfo4 + 1*perfo6
b1n =~ 0*perfo1 + lo2*perfo2 + lo3*perfo4 + 1*perfo6
perfo1 ~~ res*perfo1
perfo2 ~~ res*perfo2
perfo4 ~~ res*perfo4
perfo6 ~~ res*perfo6
lo2 > 0
lo3 > 0
'

fitbasis <- growth(basis, data = wisc3raw, mimic = "mplus")
summary(fitbasis, fit.measures = TRUE)

# ex5: latent basis growth model with predictor

basispred <- '
b0n =~ 1*perfo1 + 1*perfo2 + 1*perfo4 + 1*perfo6
b1n =~ 0*perfo1 + lo2*perfo2 + lo3*perfo4 + 1*perfo6
b0n ~ grad 
b1n ~ grad
perfo1 ~~ res*perfo1
perfo2 ~~ res*perfo2
perfo4 ~~ res*perfo4
perfo6 ~~ res*perfo6
lo2 > 0
lo3 > 0
'

fitbasispred <- growth(basispred, data = wisc3raw, mimic = "mplus")
summary(fitbasispred, fit.measures = TRUE)
inspect(fitbasispred, 'r2')
