# Install the lavaan package.

# install.packages("lavaan", dependencies=TRUE)

# Load the lavaan package.

library(lavaan)

# Import the data and name the variables.

wisc3miss <- read.table("C:/Users/Gina/Dropbox/APA Workshop/wisc3miss.dat", quote = "\"")

names(wisc3miss) = c('id', 'verb1', 'verb2', 'verb4', 'verb6', 'perfo1', 'perfo2', 'perfo4', 'perfo6',
                     'info1', 'comp1', 'simi1', 'voca1', 'info6', 'comp6', 'simi6', 'voca6', 'momed', 'grad', 'constant')

# Attach the data set.

attach(wisc3miss)

# Create missing data indicators.

wisc3miss$perfo4r = 0
wisc3miss$perfo4r[perfo4 == -99] <- 1
wisc3miss$perfo6r = 0
wisc3miss$perfo6r[perfo6 == -99] <- 1

# Recode the missing values.

wisc3miss[wisc3miss==-99] <- NA

# Correlate the missing data indicators with the analysis variables.  Use pairwise deletion.

auxiliary <- wisc3miss[c('perfo1','perfo2','momed','grad')]
indicators <- wisc3miss[c('perfo4r','perfo6r')]
cor(auxiliary, indicators, use = "pairwise.complete.obs")

# Example 1: Identify correlates of missingness.
# Correlate the missing data indicators with the analysis variables.  Use FIML estimation.

indicatorcorrs <- '
perfo1 ~~ perfo1
perfo2 ~~ perfo2
grad ~~ grad
momed ~~ momed
perfo4r ~~ perfo4r
perfo6r ~~ perfo6r
perfo1 ~~ perfo2 + grad + momed + perfo4r + perfo6r
perfo2 ~~ grad + momed + perfo4r + perfo6r
grad ~~ momed + perfo4r + perfo6r
momed ~~ perfo4r + perfo6r
perfo4r ~~ perfo6r
'

fitindicatorcorrs <- sem(indicatorcorrs, data = wisc3miss, meanstructure = TRUE, mimic = "mplus")
summary(fitindicatorcorrs, standardize = TRUE, fit.measures = TRUE)

# Example 2: Fit a latent basis growth model using FIML estimation.

basis <- '
b_0n =~ 1*perfo1 + 1*perfo2 + 1*perfo4 + 1*perfo6
b_1n =~ 0*perfo1 + lambda_2*perfo2 + lambda_3*perfo4 + 1*perfo6
perfo1 ~~ res*perfo1
perfo2 ~~ res*perfo2
perfo4 ~~ res*perfo4
perfo6 ~~ res*perfo6
lambda_2 > 0
lambda_3 > 0
'

fitbasis <- growth(basis, data = wisc3miss, mimic = "mplus")
summary(fitbasis, fit.measures = TRUE)

# Example 3: Fit a latent basis growth model with an incomplete covariate.

basispred <- '
grad ~ 1
grad ~~ grad
b_0n =~ 1*perfo1 + 1*perfo2 + 1*perfo4 + 1*perfo6
b_1n =~ 0*perfo1 + lambda_2*perfo2 + lambda_3*perfo4 + 1*perfo6
b_0n ~ grad 
b_1n ~ grad
perfo1 ~~ res*perfo1
perfo2 ~~ res*perfo2
perfo4 ~~ res*perfo4
perfo6 ~~ res*perfo6
lambda_2 > 0
lambda_3 > 0
'

fitbasispred <- growth(basispred, data = wisc3miss, mimic = "mplus", estimator = "mlr", fixed.x = FALSE)
summary(fitbasispred, fit.measures = TRUE)
inspect(fitbasispred, 'r2')

# Example 4: Fit a latent basis growth model with a manually specified auxiliary variable.
# The saturated correlates model resulted in convergence issues, so use the the extra
# dependent variable model to incorporate the auxiliary variable.  Link the auxiliary
# variable (momed) to the covariate (grad) with regression.

basisaux <- '
grad ~ 1
momed ~ 1
grad ~~ grad
momed ~~ momed
b_0n =~ 1*perfo1 + 1*perfo2 + 1*perfo4 + 1*perfo6
b_1n =~ 0*perfo1 + lambda_2*perfo2 + lambda_3*perfo4 + 1*perfo6
b_0n ~ grad
b_1n ~ grad
momed ~ grad
perfo1 ~~ res*perfo1
perfo2 ~~ res*perfo2
perfo4 ~~ res*perfo4
perfo6 ~~ res*perfo6
momed ~~ perfo1 + perfo2 + perfo4 + perfo6
momed ~~ 0*b_0n + 0*b_1n
lambda_2 > 0
lambda_3 > 0
'

fitbasisaux <- growth(basisaux, data = wisc3miss, mimic = "mplus", estimator = "mlr", fixed.x = FALSE)
summary(fitbasisaux, fit.measures = TRUE)
inspect(fitbasisaux, 'r2')
