################################################################################
# Title: Verbal factor at Ages 6 and 11 Years Configural Invariance
# File: Session L - Computer Programs/prog20_1fac2times_config.R
# Source File: Session L - Computer Programs/prog20_1fac2times_config.out
# Created: Tue Jun 21 00:15:18 2011
################################################################################
# TranslateOpenMx library (Version 0.1)
# Some parameters were constrained to equality based on Mplus output;
#    please check that this constraint is correct.
################################################################################

# load OpenMx
library(OpenMx)

# load data
rto8age2 <- read.table('rto8age2.dat', na.string="c('USEVAR' , '='      , 'info_06', 'voca_06', 'comp_06', 'simi_06', 'info_11', 'voca_11', 'comp_11', 'simi_11')")
names(rto8age2) <- c('id', 'moeducat', 'age_06', 'info_06', 'comp_06',
    'simi_06', 'voca_06', 'picc_06', 'pica_06', 'bloc_06',
    'obje_06', 'age_11', 'info_11', 'comp_11', 'simi_11',
    'voca_11', 'picc_11', 'pica_11', 'bloc_11', 'obje_11')

# specify model
VerbalModel <- mxModel("Verbal factor at Ages 6 and 11 Years Configural Invariance",
    type="RAM",
    # specify data and variables
    mxData(rto8age2, "raw"),
    manifestVars=c('info_06', 'voca_06', 'comp_06', 'simi_06', 'info_11', 'voca_11', 'comp_11', 'simi_11'),
    latentVars=c('verb_06', 'verb_11'),
    # specify 'BY' parameter(s)
    mxPath(from='verb_06', to=c('info_06', 'voca_06', 'comp_06', 'simi_06'), arrows=1,
        free=TRUE, values=c(4.451, 5.039, 6.850, 4.590), labels=c('p1', 'p2', 'p3', 'p4')),
    # specify 'BY' parameter(s)
    mxPath(from='verb_11', to=c('info_11', 'voca_11', 'comp_11', 'simi_11'), arrows=1,
        free=TRUE, values=c(4.451, 4.102, 4.006, 4.551), labels=c('p1', 'p5', 'p6', 'p7')),
    # specify 'WITH' parameter(s)
    mxPath(from='verb_06', to='verb_11', arrows=2,
        free=TRUE, values=1.837, labels='p8'),
    # specify 'Mean' parameter(s)
    mxPath(from='one', to=c('verb_06', 'verb_11'), arrows=1,
        free=c(FALSE,  TRUE), values=c(0.000, 6.455), labels=c(NA  , 'p9')),
    # specify 'Intercept' parameter(s)
    mxPath(from='one', to=c('info_06', 'voca_06', 'comp_06', 'simi_06', 'info_11', 'voca_11', 'comp_11', 'simi_11'), arrows=1,
        free=TRUE, values=c(19.776, 20.396, 21.797, 14.903, 19.776, 17.970, 19.317, 11.922), labels=c('p10', 'p11', 'p12', 'p13', 'p10', 'p14', 'p15', 'p16')),
    # specify 'Variance' parameter(s)
    mxPath(from=c('verb_06', 'verb_11'), to=c('verb_06', 'verb_11'), arrows=2,
        free=c(FALSE,  TRUE), values=c(1.000, 5.834), labels=c(NA   , 'p17')),
    # specify 'Variance' parameter(s)
    mxPath(from=c('info_06', 'voca_06', 'comp_06', 'simi_06', 'info_11', 'voca_11', 'comp_11', 'simi_11'), to=c('info_06', 'voca_06', 'comp_06', 'simi_06', 'info_11', 'voca_11', 'comp_11', 'simi_11'), arrows=2,
        free=TRUE, values=c(17.447, 13.998, 47.511, 35.810, 47.094, 23.268, 73.851, 88.919), labels=c('p18', 'p19', 'p20', 'p21', 'p22', 'p23', 'p24', 'p25')))

# run model
VerbalModelResults <- mxRun(VerbalModel)

# view summary of results
summary(VerbalModelResults)
