##########################################

### Autoregressive Model 0 - No coupling 

data<-read.table("nlsy_ach_bpi1.dat",header=F,colClasses="numeric",
na.string=".")

#paste command - pattern to name columns
#paste0 = paste command with no separation
#paste0("tot",4:14) = "tot4","tot5",..."tot14"

names(data)<-c("id","race","sex","m_birth","ldisabil", 
	paste0("dep",4:14),paste0("tot",4:14),
	paste0("anti",4:14),paste0("axdp",4:14),
	paste0("math",5:14),paste0("rec",5:14),
	paste0("comp",4:14),paste0("pvt",4:14))

t<-which(data$ldisabil==1)
data<-data[-t,]
#access data columns easily by attaching it
attach(data)



##Define variables

    data$total8  = (((dep8  + anti8  + axdp8)-5.039)/4.076)*10+50;
    data$total9  = (((dep9  + anti9  + axdp9)-5.039)/4.076)*10+50;
    data$total10 = (((dep10 + anti10 + axdp10)-5.039)/4.076)*10+50;
    data$total11 = (((dep11 + anti11 + axdp11)-5.039)/4.076)*10+50;
    data$total12 = (((dep12 + anti12 + axdp12)-5.039)/4.076)*10+50;
    data$total13 = (((dep13 + anti13 + axdp13)-5.039)/4.076)*10+50;
    data$total14 = (((dep14 + anti14 + axdp14)-5.039)/4.076)*10+50;
##Define variables

    data$pvt8 = ((pvt8-82.130)/16.745)*10+50;
    data$pvt9 = ((pvt9-82.130)/16.745)*10+50;
    data$pvt10 = ((pvt10-82.130)/16.745)*10+50;
    data$pvt11 = ((pvt11-82.130)/16.745)*10+50;
    data$pvt12 = ((pvt12-82.130)/16.745)*10+50;
    data$pvt13 = ((pvt13-82.130)/16.745)*10+50;
    data$pvt14 = ((pvt14-82.130)/16.745)*10+50;

#### Autoregressive models ####


 
acl0<-'

#####
#BPI#
#####

#Modeling True Score

lt8=~1*total8
lt9=~1*total9
lt10=~1*total10
lt11=~1*total11
lt12=~1*total12
lt13=~1*total13
lt14=~1*total14

## AutoRegressions
lt9~beta_1*lt8
lt10~beta_1*lt9
lt11~beta_1*lt10
lt12~beta_1*lt11
lt13~beta_1*lt12
lt14~beta_1*lt13

# Means for Total
total8+total9+total10+total11+total12+total13+total14~1
lt8+lt9+lt10+lt11+lt12+lt13+lt14~0*1

##Time-Specific Variance
total8~~su*total8
total9~~su*total9
total10~~su*total10
total11~~su*total11
total12~~su*total12
total13~~su*total13
total14~~su*total14

#Variance of True Scores
lt8~~lt8
lt9~~slt*lt9
lt10~~slt*lt10
lt11~~slt*lt11
lt12~~slt*lt12
lt13~~slt*lt13
lt14~~slt*lt14


#####
#PVT#
#####

##Modeling True Score
lp8=~1*pvt8
lp9=~1*pvt9
lp10=~1*pvt10
lp11=~1*pvt11
lp12=~1*pvt12
lp13=~1*pvt13
lp14=~1*pvt14

## AutoRegressions
lp9~gamma_1*lp8
lp10~gamma_1*lp9
lp11~gamma_1*lp10
lp12~gamma_1*lp11
lp13~gamma_1*lp12
lp14~gamma_1*lp13

#Means for PVT
pvt8+pvt9+pvt10+pvt11+pvt12+pvt13+pvt14~1
lp8+lp9+lp10+lp11+lp12+lp13+lp14~0*1

##Time-Specific Variance
pvt8~~sigma2_s*pvt8
pvt9~~sigma2_s*pvt9
pvt10~~sigma2_s*pvt10
pvt11~~sigma2_s*pvt11
pvt12~~sigma2_s*pvt12
pvt13~~sigma2_s*pvt13
pvt14~~sigma2_s*pvt14

## Latent Variances 

lp8~~start(68)*lp8
lp9~~slp*lp9
lp10~~slp*lp10
lp11~~slp*lp11
lp12~~slp*lp12
lp13~~slp*lp13
lp14~~slp*lp14


##MULTIVARIATE INFO

#Specific Covariance
    pvt8   ~~(c_su)*total8  
    pvt9   ~~(c_su)*total9  
    pvt10  ~~(c_su)*total10 
    pvt11  ~~(c_su)*total11
    pvt12  ~~(c_su)*total12
    pvt13  ~~(c_su)*total13
    pvt14  ~~(c_su)*total14

#Correlations among true scores

    lt8 ~~ start(-14)*lp8
    lt9 ~~ c_ltlp*lp9
    lt10 ~~ c_ltlp*lp10
    lt11 ~~ c_ltlp*lp11
    lt12 ~~ c_ltlp*lp12
    lt13 ~~ c_ltlp*lp13
    lt14 ~~ c_ltlp*lp14
'

acl0_fit<-lavaan(acl0,data=data,missing='ML')
summary(acl0_fit)

